pub struct DylibOpts {
pub interpreter: Option<String>,
pub async_: AsyncFilterSet,
pub stack_pointer: StackPointer,
}Fields
interpreter: Option<String>The interpreter name to insert into the WASM_DYLINK_NEEDED section
encoded as dylink.0.
async_: AsyncFilterSetstack_pointer: StackPointerWhere the stack pointer is located in the ABI of the generated dylib.
For WASIp2-and-prior the global option should be used, and for
WASIp3-and-later the task-context option should be used.